@@ -1,4 +1,5 @@
 from .copy import copy_vds  # NOQA
-from .enums import LOD, AccessModes, BrickSizes, Components, Dimensions, Formats, MetadataTypes, Options  # NOQA
+from .enums import (LOD, AccessModes, BrickSizes, Components, Dimensions, Formats, InitValue, MetadataTypes,  # NOQA
+                    Options)
 from .utils import METADATATYPE_TO_OVDS_GET_FUNCTION, METADATATYPE_TO_OVDS_SET_FUNCTION  # NOQA
 from .writing import create_vds, write_pages  # NOQA
