@@ -7,10 +7,10 @@ import openvds
 from ovds_utils.exceptions import VDSException
 from ovds_utils.logging import get_logger
 from ovds_utils.metadata import MetadataContainer
-from ovds_utils.ovds import LOD, AccessModes, BrickSizes, Components, Dimensions, Formats, Options, create_vds
+from ovds_utils.ovds import (LOD, AccessModes, BrickSizes, Components, Dimensions, Formats, InitValue, Options,
+                             create_vds)
 from ovds_utils.ovds.utils import get_vds_info
 from ovds_utils.ovds.writing import FORMAT2FLOAT
-from dataclasses import dataclass, field
 
 logger = get_logger(__name__)
 
@@ -90,9 +90,9 @@ class Axis:
         self,
         samples: int,
         name: AnyStr,
-        unit: AnyStr,
         coordinate_min: float,
-        coordinate_max: float
+        coordinate_max: float,
+        unit: AnyStr = "unitless",
     ) -> None:
         self.samples = samples
         self.name = name
@@ -100,6 +100,9 @@ class Axis:
         self.coordinate_min = coordinate_min
         self.coordinate_max = coordinate_max
 
+    def __repr__(self) -> str:
+        return f"<Axis(name={self.name}, unit={self.unit}, range=({self.coordinate_min}, {self.coordinate_max}))>"
+
 
 class Channel:
     def __init__(
@@ -114,6 +117,7 @@ class Channel:
             chunks_count: int = None,
             vds_source=None,
             shape: Sequence[int] = None,
+            dimensions_nd=Dimensions._012,
     ) -> None:
         self._vds_source = vds_source
         self.name = name
@@ -125,6 +129,7 @@ class Channel:
         self.components = components
         self.value_range_min = value_range_min
         self.value_range_max = value_range_max
+        self.dimensions_nd = dimensions_nd
 
     def __repr__(self) -> str:
         return f"<Channel(name={self.name}, unit={self.unit}, format={self.format.name})>"
@@ -213,22 +218,21 @@ class Channel:
 
 class VDS:
     def __init__(
-            self,
-            path: AnyStr,
-            connection_string: AnyStr = "",
-            databrick_size: BrickSizes = BrickSizes.BrickSize_128,
-            metadata_dict: MetadataContainer = {},
-            format: Formats = Formats.R32,
-            channels_data: List[np.array] = None,
-            channels: List[Channel] = None,
-            axes: List[Axis] = None,
-            lod=LOD._0,
-            dimensions_nd=Dimensions.Dimensions_012,
-            negative_margin: int = 0,
-            positive_margin: int = 0,
-            options: Options = Options._0,
-            full_resolution_dimension: int = 0,
-            brick_size_2d_multiplier: int = 4,
+        self,
+        path: AnyStr,
+        connection_string: AnyStr = "",
+        databrick_size: BrickSizes = BrickSizes._128,
+        metadata_dict: MetadataContainer = {},
+        channels_data: List[np.array] = None,
+        channels: List[Channel] = None,
+        axes: List[Axis] = None,
+        lod: LOD = LOD._None,
+        negative_margin: int = 0,
+        positive_margin: int = 0,
+        options: Options = Options._None,
+        full_resolution_dimension: int = 0,
+        brick_size_2d_multiplier: int = 4,
+        init_value: InitValue = InitValue.zero
     ) -> None:
         super().__init__()
         self.path = path
@@ -250,22 +254,20 @@ class VDS:
                     axes=axes,
                     metadata_dict=metadata_dict,
                     channels_data=channels_data,
-                    format=format,
                     access_mode=AccessModes.Create,
-                    dimensions_nd=dimensions_nd,
                     lod=lod,
                     positive_margin=positive_margin,
                     negagitve_margin=negative_margin,
                     options=options,
                     full_resolution_dimension=full_resolution_dimension,
-                    brick_size_2d_multiplier=brick_size_2d_multiplier
+                    brick_size_2d_multiplier=brick_size_2d_multiplier,
+                    init_value=init_value
                 )
                 self = self.__init__(
                     path=path,
                     connection_string=connection_string,
                     databrick_size=databrick_size,
                     metadata_dict=metadata_dict,
-                    format=format,
                 )
                 return
             else:
@@ -290,7 +292,7 @@ class VDS:
             self._channels[j['name']] = Channel(
                 vds_source=self._vds_source,
                 shape=self.shape,
-                components=getattr(Components, j['components']),
+                components=getattr(Components, j['components'].replace("Components", "")),
                 name=j['name'],
                 unit=j['unit'],
                 format=getattr(
@@ -311,7 +313,7 @@ class VDS:
 
     @property
     def axes(self) -> List[Axis]:
-        return list(self._axes.values())
+        return list(self._axes.values())[::-1]
 
     def get_channel(self, name: AnyStr) -> Channel:
         return self._channels[name]
@@ -329,10 +331,41 @@ class VDS:
     def metadata(self) -> MetadataContainer:
         return MetadataContainer.get_from_layout(self._layout)
 
+    @property
+    def negative_margin(self) -> int:
+        return self._layout.getLayoutDescriptor().getNegativeMargin()
+
+    @property
+    def positive_margin(self) -> int:
+        return self._layout.getLayoutDescriptor().getPositiveMargin()
+
+    @property
+    def full_resolution_dimension(self) -> int:
+        return self._layout.getLayoutDescriptor().fullResolutionDimension
+
+    @property
+    def options(self):
+        name = str(self._layout.getLayoutDescriptor().getOptions()).replace("Options.Options", "")
+        return getattr(Options, name)
+
+    @property
+    def brick_size_2d_multiplier(self) -> int:
+        return self._layout.getLayoutDescriptor().brickSizeMultiplier2D
+
+    @property
+    def databrick_size(self) -> BrickSizes:
+        name = str(self._layout.getLayoutDescriptor().getBrickSize()).replace("BrickSize.BrickSize", "")
+        return getattr(BrickSizes, name)
+
+    @property
+    def lod(self) -> LOD:
+        name = str(self._layout.getLayoutDescriptor().getLODLevels()).replace("LODLevels.LODLevels", "")
+        return getattr(LOD, name)
+
     def __str__(self) -> str:
         return f"<{self.__class__.__qualname__}(path={self.path})>"
 
-    @property
+    @ property
     def axis_descriptors(self):
         return tuple((
             self._axes[k].name,
@@ -340,26 +373,25 @@ class VDS:
             self._axes[k].samples
         ) for k in self._axes)[::-1]
 
-    @property
+    @ property
     def shape(self):
         return tuple(self._axes[k].samples for k in self._axes)[::-1]
 
-    @staticmethod
+    @ staticmethod
     def create(
         path: AnyStr,
         connection_string: AnyStr,
         databrick_size: BrickSizes,
         access_mode: AccessModes,
-        format: Formats,
         channels: List[Channel],
         axes: List[Axis],
-        dimensions_nd: Dimensions,
         positive_margin: int,
         negagitve_margin: int,
         full_resolution_dimension: int,
         brick_size_2d_multiplier: int,
         lod: LOD,
         options: Options,
+        init_value: InitValue,
         metadata_dict: MetadataContainer = None,
         channels_data: List[np.array] = None,
     ):
@@ -371,15 +403,14 @@ class VDS:
             axes=axes,
             databrick_size=databrick_size.value,
             access_mode=access_mode.value,
-            format=format.value,
             lod=lod.value,
-            dimensions_nd=dimensions_nd.value,
             channels_data=channels_data,
             negative_margin=negagitve_margin,
             positive_margin=positive_margin,
             options=options.value,
             brick_size_2d_multiplier=brick_size_2d_multiplier,
             full_resolution_dimension=full_resolution_dimension,
+            init_value=init_value,
             close=True
         )
 
@@ -396,7 +427,7 @@ class VDS:
             channel: int = 0,
             maxPages: int = 8,
             chunkMetadataPageSize: int = 1024,
-            dimensionsND=Dimensions.Dimensions_012,
+            dimensionsND=Dimensions._012,
     ):
         access_manager = openvds.getAccessManager(self._vds_source)
         accessor = access_manager.createVolumeDataPageAccessor(
